# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""make null relocatable for testing

Revision ID: 257537f99abc
Revises: 42a9e35d0809
Create Date: 2021-09-14 09:52:41.666489

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "257537f99abc"
down_revision = "42a9e35d0809"
branch_labels = None
depends_on = None

condor_content = """executable = null.sh
arguments = {{arguments}}

output = null.out
error = null.err
log = condor.log
should_transfer_files = yes
transfer_input_files = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin/null

{{#remote-cv}}
#run on a condor node in CV-NAASC
requirements = (CVPOST == True)
+partition = "CVPOST"
{{/remote-cv}}

{{#remote}}
#run on a NMT condor node. (naming consistent with vlass-seci)
requirements = (HasLustre =!= True)
{{/remote}}

queue

"""


old_content = """executable = null.sh
arguments = {{arguments}}

output = null.out
error = null.err
log = null.log
should_transfer_files = yes
transfer_input_files = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin/null


queue

"""


def upgrade():
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{condor_content}' WHERE filename='null.condor'
        """
    )


def downgrade():
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{old_content}' WHERE filename='null.condor'
        """
    )
