# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""multistage calibration scripts

Revision ID: bd5f8a4c61da
Revises: 47368b3802a9
Create Date: 2021-10-04 16:12:48.550412

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "bd5f8a4c61da"
down_revision = "47368b3802a9"
branch_labels = None
depends_on = None


fetch_content = """#!/bin/sh
set -o errexit

export HOME=$TMPDIR

./framework.sh -d .
chmod 770 .
cd rawdata/
../productfetcher --product-locator $1
cd ../

"""

envoy_content = """#!/bin/sh
set -o errexit

export HOME=$TMPDIR
{{#remote}}
export CAPO_PATH=$(readlink -f $TMPDIR)
export CAPO_PROFILE={{profile}}
{{/remote}}

./casa_envoy --standard-cal $1 $2

"""

convey_content = """#!/bin/sh
set -o errexit

export HOME=$TMPDIR

./conveyor --deliver $1
"""

old_content = """#!/bin/sh

export HOME=$TMPDIR

set -o errexit
./framework.sh -d .
chmod 770 .
cd rawdata/
../productfetcher --product-locator $1
cd ../
./casa_envoy --standard-cal $3 $4
./conveyor --deliver $3

"""


def upgrade():
    op.execute(
        """
        DELETE FROM workflow_templates WHERE filename='std_calibration.sh'
        """
    )
    op.execute(
        f"""
            INSERT INTO workflow_templates (filename, content, workflow_name)
            VALUES ('std_calibration_fetch.sh', E'{fetch_content}', 'std_calibration')
            """
    )
    op.execute(
        f"""
            INSERT INTO workflow_templates (filename, content, workflow_name)
            VALUES ('std_calibration_envoy.sh', E'{envoy_content}', 'std_calibration')
            """
    )
    op.execute(
        f"""
        INSERT INTO workflow_templates (filename, content, workflow_name)
        VALUES ('std_calibration_convey.sh', E'{convey_content}', 'std_calibration')
        """
    )


def downgrade():
    op.execute(
        """
        DELETE FROM workflow_templates
        WHERE filename like ('std_calibration_%.sh')
        AND workflow_name = 'std_calibration'
        """
    )

    op.execute(
        f"""
        INSERT INTO workflow_templates (filename, content, workflow_name)
        VALUES ('std_calibration.sh', E'{old_content}', 'std_calibration')
        """
    )
